"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.add_api_call = void 0;
const Kinara_Engr_Api_Users_1 = require("../dataModels/Kinara_Engr_Api_Users");
const Kinara_Engr_Api_Tokens_1 = require("../dataModels/Kinara_Engr_Api_Tokens");
const kinara_engr_api_hist_table_1 = require("../dataModels/kinara_engr_api_hist_table");
/**
 * @desc This async function return user_name base on token.
 *
 * @param  {string} token Api token.
 * @return {JSON} user_name from database.
 */
function get_user_id(token) {
    return __awaiter(this, void 0, void 0, function* () {
        const response = yield Kinara_Engr_Api_Tokens_1.APIToken.findOne({
            attributes: ["user_Id"],
            where: { token: token },
            raw: true,
        }).then((result) => __awaiter(this, void 0, void 0, function* () {
            return yield Kinara_Engr_Api_Users_1.APIUsers.findOne({
                attributes: ["user_name"],
                where: { ID: result.user_Id },
                raw: true,
            });
        }));
        console.log(response);
        return response;
    });
}
/**
 * In this we are save api calling in history tables.
 * Note: don't send server response.
 * @param  {Request} req            APi request
 * @param  {Response} res           APi response json, this should be json, created for api response.
 * @param  {String} apiErrorLabel   APi error reason, if success then NA,
 *                                  other reason eg. 500 --> internal error.
 * @param  {string} apiStatus       Api status  it can be success or fail.
 * @param  {string} logicStatus     Api logic status  it can be success or fail.
 * @param  {Number} apiStatusCode   Api status code, it can be 500, 200, etc.
 *
 * @return {Boolean} true if successfully inserted otherwise false.
 */
const add_api_call = (req, res, apiErrorLabel, apiStatus, logicStatus, apiStatusCode) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    try {
        // Fetch the token from request header
        let token = (_a = req.headers["authorization"]) === null || _a === void 0 ? void 0 : _a.split(" ")[1];
        // Get user-id
        yield get_user_id(token).then((result) => __awaiter(void 0, void 0, void 0, function* () {
            // Fetch user_name else "NA"
            let apiUserId = result.user_name || "NA";
            console.log(apiUserId);
            // Get the original URL
            let apiRoute = req.originalUrl;
            // Considering last value of a string,
            // Ex. /api/colending --> colending
            let apiName = apiRoute.split("/")[1];
            // Inserting api details in api_hist table
            let response = yield kinara_engr_api_hist_table_1.APIHistoryTable.create({
                application_id: "N/A",
                user_id: apiUserId,
                api_route: apiRoute,
                api_name: apiName,
                api_error_label: apiErrorLabel,
                status_code: apiStatusCode,
                api_status: apiStatus,
                logic_status: logicStatus,
                // Converting JSON (req and res) to string and replacing `"` to `'` while inserting value.
                api_request: JSON.stringify(req.body).replace(/"/g, `'`),
                api_response: JSON.stringify(res).replace(/"/g, `'`),
                server_type: process.env.SERVER_TYPE,
                // Current Datetime with India local time zone
                api_request_on: new Date().toLocaleString("en-US", {
                    timeZone: "Asia/Calcutta",
                    hour12: false,
                }),
            });
            // Capture the Log
            console.log(response instanceof Kinara_Engr_Api_Tokens_1.APIToken);
            return response instanceof Kinara_Engr_Api_Tokens_1.APIToken;
        }));
    }
    catch (ex) {
        console.log(`API History Exception Catch - ${ex}`);
    }
});
exports.add_api_call = add_api_call;
