"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DbConnection = void 0;
/**
 * DESCRIPTION: SEQUELIZE ORM AND QUERY EXECUTION FUNCTION
 * CREATED BY: VIKAS
 * CREATED ON: 19/04/2021
 * MODIFIED BY: VIKAS
 * MODIFIED ON: 03/05/2021
 */
const sequelize_1 = require("sequelize");
/**
 * @desc This class returns database connection string,
 
 * SERVER_TYPE can be True or False. If the value is False,
 * it will allow to connection to external database like RDS.
 *
 * @constructor
 * @param {String} PORT - A string param.
 * @param {String} HOST - A string param.
 * @param {String} USERNAME - A string param.
 * @param {String} PASSWORD - A string param.
 * @param {String} DATABASE - A string param.
 * @param {Boolean} [SERVER_TYPE = true] - An optional param with a default value
 */
class DbConnection {
    constructor(PORT, HOST, USERNAME, PASSWORD, DATABASE, SERVER_TYPE = true) {
        this.PORT = PORT;
        this.HOST = HOST;
        this.USERNAME = USERNAME;
        this.PASSWORD = PASSWORD;
        this.DATABASE = DATABASE;
        this.SERVER_TYPE = SERVER_TYPE;
    }
    /**
     * @desc Function that handles the connection sting
     */
    connectMySql() {
        // Validate connection details
        if (this.SERVER_TYPE) {
            // Multiple Database Connectivity
            switch (process.env.SERVER_TYPE) {
                // Staging Database Connection
                case "STAGING":
                    this.PORT = process.env.STAGEDBPORT;
                    this.HOST = process.env.STAGEDBHOST;
                    this.USERNAME = process.env.STAGEDBUSER;
                    this.PASSWORD = process.env.STAGEDBPWD;
                    this.DATABASE = process.env.STAGEDB;
                    break;
                // Production Database Connection
                case "PROD":
                    this.PORT = process.env.PRODDBPORT;
                    this.HOST = process.env.PRODDBHOST;
                    this.USERNAME = process.env.PRODDBUSER;
                    this.PASSWORD = process.env.PRODDBPWD;
                    this.DATABASE = process.env.PRODDB;
                    break;
                // Dev | Local Database Connection
                default:
                    this.PORT = process.env.DEVDBPORT;
                    this.HOST = process.env.DEVDBHOST;
                    this.USERNAME = process.env.DEVDBUSER;
                    this.PASSWORD = process.env.DEVDBPWD;
                    this.DATABASE = process.env.DEVDB;
            }
        }
        // Manual Connection
        else {
            this.PORT = process.env.PORT;
            this.HOST = process.env.HOST;
            this.USERNAME = process.env.USERNAME;
            this.PASSWORD = process.env.PASSWORD;
            this.DATABASE = this.DATABASE;
        }
        console.log(this.PORT, this.HOST, this.DATABASE);
        // Creating a connection string using Sequelize
        return new sequelize_1.Sequelize(this.DATABASE, this.USERNAME, this.PASSWORD, {
            host: this.HOST,
            port: this.PORT,
            dialect: "mysql",
            timezone: "+05:30",
        });
    }
}
exports.DbConnection = DbConnection;
