/**
 * DESCRIPTION: AGG_MLY_LMS_ALM_DETAILS data model used to
 *              Define AGG_MLY_LMS_ALM_DETAILS ORM data model object and
 *              to fetch the ALM details (Asset and liability management)
 * CREATED BY: ANITA MS
 * CREATED DATE: 01/06/2021
 * MODIFIED BY:
 * MODIFIED DATE:
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IALMDetailsAPI {
  date_key: number;
  particular_type: string;
  particular_category: string;
  component: string;
  one_month: number;
  two_month: number;
  three_month: number;
  four_month: number;
  five_month: number;
  six_month: number;
  six_twelve_month: number;
  one_three_year: number;
  three_five_years: number;
  five_plus_years: number;
  total_amount: number;
}

// Class that implements the ALM Details interface attributes
export class ALMDetails
  extends Model<IALMDetailsAPI>
  implements IALMDetailsAPI
{
  public date_key!: number;
  public particular_type!: string;
  public particular_category!: string;
  public component!: string;
  public one_month!: number;
  public two_month!: number;
  public three_month!: number;
  public four_month!: number;
  public five_month!: number;
  public six_month!: number;
  public six_twelve_month!: number;
  public one_three_year!: number;
  public three_five_years!: number;
  public five_plus_years!: number;
  public total_amount!: number;
}

// Initializing the database table structure
ALMDetails.init(
  {
    date_key: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    particular_type: {
      type: DataTypes.STRING(20),
      allowNull: true,
    },
    particular_category: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    component: {
      type: DataTypes.STRING(20),
      allowNull: true,
    },
    one_month: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    two_month: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    three_month: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    four_month: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    five_month: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    six_month: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    six_twelve_month: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    one_three_year: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    three_five_years: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    five_plus_years: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    total_amount: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "AGG_MLY_LMS_ALM_DETAILS",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
ALMDetails.removeAttribute("id"); // Primary Key Attribute
ALMDetails.removeAttribute("createdAt"); // Created Date Attribute
ALMDetails.removeAttribute("updatedAt"); // Update Date Attribute
