/**
 * DESCRIPTION: Kinara_Engr_Api_BillsGenerated data model used to
 *              Define Kinara_Engr_Api_BillsGenerated ORM data model object and
 *              to fetch the bill details from the perdix
 *              and save bill details to the table
 * CREATED BY: ANITA MS
 * CREATED DATE: 01/06/2021
 * MODIFIED BY:
 * MODIFIED DATE:
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IBillGeneratedAPI {
  ID: number;
  loan_account_no: string;
  product_code: string;
  product_type: string;
  loan_type: string;
  business_urn: string;
  business_name: string;
  customer_phone: string;
  applicant_fname: string;
  applicant_mname: string;
  applicant_lname: string;
  applicant_phone: string;
  tot_principle_due: number;
  tot_normal_interest_due: number;
  tot_demand_due: number;
  tot_penal_interest_due: number;
  booked_not_due_penal_interest_due: number;
  tot_fee_due: number;
  tot_bill_amount: number;
  bill_type: string;
  aggr_guid: string;
  aggr_req_id: string;
  platform_mob_no: string;
  created_timest: Date;
  bill_paid: string;
  payment_status: string;
  platform_bill_no: string;
  tran_ref_no: string;
  utr1: string;
  utr2: string;
  tran_amount: number;
  tran_timest: Date;
  kin_receipt_no: string;
  updated_perdix: string;
  updated_timest: Date;
  perdix_tran_id: string;
  perdix_response_type: string;
  aggr_id: number;
  agent_number: string;
  created_by: string;
}

// Class that implements the bill generated Details interface attributes
export class BillGenerated
  extends Model<IBillGeneratedAPI>
  implements IBillGeneratedAPI
{
  public ID!: number;
  public loan_account_no!: string;
  public product_code!: string;
  public product_type!: string;
  public loan_type!: string;
  public business_urn!: string;
  public business_name!: string;
  public customer_phone!: string;
  public applicant_fname!: string;
  public applicant_mname!: string;
  public applicant_lname!: string;
  public applicant_phone!: string;
  public tot_principle_due!: number;
  public tot_normal_interest_due!: number;
  public tot_demand_due!: number;
  public tot_penal_interest_due!: number;
  public booked_not_due_penal_interest_due!: number;
  public tot_fee_due!: number;
  public tot_bill_amount!: number;
  public bill_type!: string;
  public aggr_guid!: string;
  public aggr_req_id!: string;
  public platform_mob_no!: string;
  public created_timest!: Date;
  public bill_paid!: string;
  public payment_status!: string;
  public platform_bill_no!: string;
  public tran_ref_no!: string;
  public utr1!: string;
  public utr2!: string;
  public tran_amount!: number;
  public tran_timest!: Date;
  public kin_receipt_no!: string;
  public updated_perdix!: string;
  public updated_timest!: Date;
  public perdix_tran_id!: string;
  public perdix_response_type!: string;
  public aggr_id!: number;
  public agent_number!: string;
  public created_by!: string;
}

// Initializing the database table structure
BillGenerated.init(
  {
    ID: {
      type: DataTypes.BIGINT,
      allowNull: true,
    },
    loan_account_no: {
      type: DataTypes.STRING(20),
      allowNull: true,
    },
    product_code: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    product_type: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    loan_type: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    business_urn: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    business_name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    customer_phone: {
      type: DataTypes.STRING(15),
      allowNull: true,
    },
    applicant_fname: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    applicant_mname: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    applicant_lname: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    applicant_phone: {
      type: DataTypes.STRING(15),
      allowNull: true,
    },
    tot_principle_due: {
      type: DataTypes.DECIMAL(14, 2),
      allowNull: true,
    },
    tot_normal_interest_due: {
      type: DataTypes.DECIMAL(14, 2),
      allowNull: true,
    },
    tot_demand_due: {
      type: DataTypes.DECIMAL(14, 2),
      allowNull: true,
    },
    tot_penal_interest_due: {
      type: DataTypes.DECIMAL(14, 2),
      allowNull: true,
    },
    booked_not_due_penal_interest_due: {
      type: DataTypes.DECIMAL(14, 2),
      allowNull: true,
    },
    tot_fee_due: {
      type: DataTypes.DECIMAL(14, 2),
      allowNull: true,
    },
    tot_bill_amount: {
      type: DataTypes.DECIMAL(14, 2),
      allowNull: true,
    },
    bill_type: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    aggr_guid: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    aggr_req_id: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    platform_mob_no: {
      type: DataTypes.STRING(15),
      allowNull: true,
    },
    created_timest: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    bill_paid: {
      type: DataTypes.CHAR(1),
      allowNull: true,
    },
    payment_status: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    platform_bill_no: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    tran_ref_no: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    utr1: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    utr2: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    tran_amount: {
      type: DataTypes.DECIMAL(18, 2),
      allowNull: true,
    },
    tran_timest: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    kin_receipt_no: {
      type: DataTypes.STRING(75),
      allowNull: true,
    },
    updated_perdix: {
      type: DataTypes.CHAR(1),
      allowNull: true,
    },
    updated_timest: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    perdix_tran_id: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    perdix_response_type: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    aggr_id: {
      type: DataTypes.BIGINT,
      allowNull: true,
    },
    agent_number: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    created_by: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "Kinara_Engr_Api_BillsGenerated",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
// BillGenerated.removeAttribute("id"); // Primary Key Attribute
BillGenerated.removeAttribute("createdAt"); // Created Date Attribute
BillGenerated.removeAttribute("updatedAt"); // Update Date Attribute
