/**
 * DESCRIPTION: KINARA_ENGR_API_BUSINESS_ENTITY_DETAILS DATA MODEL USED
 *              TO FETCH THE BUSINESS DETAILS
 * CREATED BY: VIKAS
 * CREATED DATE: 20/05/2021
 * MODIFIED BY: VIKAS
 * MODIFIED DATE: 27/05/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IBusinessEntityDetails {
  customer_id: number;
  urn_no: string;
  business_constitution: string;
  first_name: string;
  business_type: string;
  business_sector: string;
  business_sub_sector: string;
  door_no: string;
  street: string;
  landmark: string;
  pincode: string;
  district: string;
  state: string;
  village_name: string;
  mailing_locality: string;
  company_email_id: string;
  loan_id: number;
}

// Class that implements the business entity details interface attributes
export class BusinessEntityDetails extends Model<IBusinessEntityDetails> {
  public customer_id!: number;
  public urn_no!: string;
  public business_constitution!: string;
  public first_name!: string;
  public business_type!: string;
  public business_sector!: string;
  public business_sub_sector!: string;
  public door_no!: string;
  public street!: string;
  public landmark!: string;
  public pincode!: string;
  public district!: string;
  public state!: string;
  public village_name!: string;
  public mailing_locality!: string;
  public company_email_id!: string;
  public loan_id!: number;
}

// Initializing the database table structure
BusinessEntityDetails.init(
  {
    customer_id: {
      type: DataTypes.BIGINT,
      allowNull: true,
    },
    urn_no: {
      type: DataTypes.STRING(16),
      allowNull: true,
    },
    business_constitution: {
      type: DataTypes.CHAR(14),
      allowNull: true,
    },
    first_name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    business_type: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    business_sector: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    business_sub_sector: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    door_no: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    street: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    landmark: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    pincode: {
      type: DataTypes.BIGINT,
      allowNull: true,
    },
    district: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    state: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    village_name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    mailing_locality: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    company_email_id: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    loan_id: {
      type: DataTypes.BIGINT,
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "Kinara_Engr_Api_BussEntityDetails",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
BusinessEntityDetails.removeAttribute("id"); // Primary Key Attribute
BusinessEntityDetails.removeAttribute("createdAt"); // Created Date Attribute
BusinessEntityDetails.removeAttribute("updatedAt"); // Update Date Attribute
