/**
 * DESCRIPTION: KINARA_ENGR_API_BUSINESSPARTNERDETAILS DATA MODEL USED
 *              TO FETCH THE DETAILS OF BUSINESS PARTNERS
 * CREATED BY: VIKAS
 * CREATED DATE: 20/05/2021
 * MODIFIED BY: VIKAS
 * MODIFIED DATE: 27/05/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IBusinessPartnerDetails {
  customer_id: number;
  Co_Applicant_name: string;
  Co_date_of_birth: Date;
  urn_no: string;
  mobile_phone: string;
  whatsapp_no: string;
  identity_proof: string;
  door_no: string;
  street: string;
  landmark: string;
  pincode: number;
  district: string;
  state: string;
  village_name: string;
  locality: string;
  Co_applicant_id_proof_no: string;
  Co_applicant_pancard_no: string;
  email: string;
  loan_id: number;
  relationship: string;
}

export class BusinessPartnerDetails extends Model<IBusinessPartnerDetails> {
  public customer_id!: number;
  public Co_Applicant_name!: string;
  public Co_date_of_birth!: Date;
  public urn_no!: string;
  public mobile_phone!: string;
  public whatsapp_no!: string;
  public identity_proof!: string;
  public door_no!: string;
  public street!: string;
  public landmark!: string;
  public pincode!: number;
  public district!: string;
  public state!: string;
  public village_name!: string;
  public locality!: string;
  public Co_applicant_id_proof_no!: string;
  public Co_applicant_pancard_no!: string;
  public email!: string;
  public loan_id!: number;
  public relationship!: string;
}

// Define customer_api ORM data model object
BusinessPartnerDetails.init(
  {
    customer_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    Co_Applicant_name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    Co_date_of_birth: {
      type: DataTypes.DATEONLY,
      allowNull: true,
    },
    urn_no: {
      type: DataTypes.STRING(16),
      allowNull: true,
    },
    mobile_phone: {
      type: DataTypes.STRING(15),
      allowNull: true,
    },
    whatsapp_no: {
      type: DataTypes.STRING(45),
      allowNull: true,
    },
    identity_proof: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    door_no: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    street: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    landmark: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    pincode: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    district: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    state: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    village_name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    locality: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    Co_applicant_id_proof_no: {
      type: DataTypes.STRING(30),
      allowNull: true,
    },
    Co_applicant_pancard_no: {
      type: DataTypes.STRING(16),
      allowNull: true,
    },
    email: {
      type: DataTypes.STRING(150),
      allowNull: true,
    },
    loan_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    relationship: {
      type: DataTypes.STRING(45),
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "Kinara_Engr_Api_BusinessPartnerDetails",
    sequelize,
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
BusinessPartnerDetails.removeAttribute("id"); // Primary Key Attribute
BusinessPartnerDetails.removeAttribute("createdAt"); // Created Date Attribute
BusinessPartnerDetails.removeAttribute("updatedAt"); // Update Date Attribute
