/**
 * DESCRIPTION: KINARA_ENGR_API_DEDUP_CUST_DETAILS DATA MODEL
 *              HAS THE CUSTOMER LOAN DETAILS
 * CREATED BY: VIKAS
 * CREATED DATE: 23/06/2021
 */
import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface for the attributes, for stricter typechecking
interface IDupCustDetails {
  cust_id: number;
  loan_id: number;
  loan_acc_no: string;
  cust_name: string;
  cust_acc_rel: string;
  account_type: string;
  urn_no: string;
  identity_prof: string;
  identity_prof_no: string;
  pan_card_no: string;
  loan_amt: number;
  EMIAmount: number;
  total_tenure: number;
  tenure_completed: number;
  Bounce_count: number;
  DelinquentDays: number;
  PrinicipalOutstanding: number;
  max_DelinquentDays: number;
  appl_date: Date;
  disb_date: Date;
  loan_status: string;
  curr_stage: string;
}

// Class that implements the api users interface attributes
export class DupCustDetails
  extends Model<IDupCustDetails>
  implements IDupCustDetails
{
  public cust_id!: number;
  public loan_id!: number;
  public loan_acc_no!: string;
  public cust_name!: string;
  public cust_acc_rel!: string;
  public account_type!: string;
  public urn_no!: string;
  public identity_prof!: string;
  public identity_prof_no!: string;
  public pan_card_no!: string;
  public loan_amt!: number;
  public EMIAmount!: number;
  public total_tenure!: number;
  public tenure_completed!: number;
  public Bounce_count!: number;
  public DelinquentDays!: number;
  public PrinicipalOutstanding!: number;
  public max_DelinquentDays!: number;
  public appl_date!: Date;
  public disb_date!: Date;
  public loan_status!: string;
  public curr_stage!: string;
}
// Define colender_loan_parameters ORM data model object
DupCustDetails.init(
  {
    cust_id: {
      type: DataTypes.INTEGER,
    },
    loan_id: {
      type: DataTypes.INTEGER,
    },
    loan_acc_no: {
      type: DataTypes.STRING(100),
    },
    cust_name: {
      type: DataTypes.STRING(100),
    },
    cust_acc_rel: {
      type: DataTypes.STRING(100),
    },
    account_type: {
      type: DataTypes.STRING(50),
    },
    urn_no: {
      type: DataTypes.STRING(16),
    },
    identity_prof: {
      type: DataTypes.STRING(100),
    },
    identity_prof_no: {
      type: DataTypes.STRING(30),
    },
    pan_card_no: {
      type: DataTypes.STRING(16),
    },
    loan_amt: {
      type: DataTypes.DOUBLE,
    },
    EMIAmount: {
      type: DataTypes.DOUBLE,
    },
    total_tenure: {
      type: DataTypes.INTEGER,
    },
    tenure_completed: {
      type: DataTypes.INTEGER,
    },
    Bounce_count: {
      type: DataTypes.INTEGER,
    },
    DelinquentDays: {
      type: DataTypes.INTEGER,
    },
    PrinicipalOutstanding: {
      type: DataTypes.INTEGER,
    },
    max_DelinquentDays: {
      type: DataTypes.INTEGER,
    },
    appl_date: {
      type: DataTypes.DATE,
    },
    disb_date: {
      type: DataTypes.DATE,
    },
    loan_status: {
      type: DataTypes.STRING(50),
    },
    curr_stage: {
      type: DataTypes.STRING(50),
    },
  },
  {
    timestamps: false,
    tableName: "Kinara_Engr_Api_Dedup_Cust_Details",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
DupCustDetails.removeAttribute("id"); // Primary Key Attribute
DupCustDetails.removeAttribute("createdAt"); // Created Date Attribute
DupCustDetails.removeAttribute("updatedAt"); // Update Date Attribute
