/**
 * DESCRIPTION: CUSTOMER_API DATA MODEL USED
 *              TO FETCH THE DEDUPE DETAILS
 * CREATED BY: VIKAS
 * CREATED DATE: 27/04/2021
 * MODIFIED BY: VIKAS
 * MODIFIED DATE: 19/05/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface for the attributes, for stricter typechecking
interface IDedupeApplicantDetails {
  customer_id: number;
  customer_name: string;
  date_of_birth: Date;
  urn_no: string;
  mobile_phone: string;
  whatsapp_no: string;
  identity_proof: string;
  id_proof_no: string;
  pan_card_no: string;
  door_no: string;
  street: string;
  landmark: string;
  pincode: number;
  district: string;
  state: string;
  village_name: string;
  locality: string;
  loan_id: number;
  relationship: string;
  hub_id: number;
  hub_name: string;
  spoke_id: number;
  spoke_name: string;
}

// Class that implements the dedup application details interface attributes
export class DedupApplicantDetails extends Model<IDedupeApplicantDetails> {
  public customer_id!: number;
  public customer_name!: string;
  public date_of_birth!: Date;
  public urn_no!: string;
  public mobile_phone!: string;
  public whatsapp_no!: string;
  public identity_proof!: string;
  public id_proof_no!: string;
  public pan_card_no!: string;
  public door_no!: string;
  public street!: string;
  public landmark!: string;
  public pincode!: number;
  public district!: string;
  public state!: string;
  public village_name!: string;
  public locality!: string;
  public loan_id!: number;
  public relationship!: string;
  public hub_id!: number;
  public hub_name!: string;
  public spoke_id!: number;
  public spoke_name!: string;
}

// Initializing the database table structure
DedupApplicantDetails.init(
  {
    customer_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    customer_name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    date_of_birth: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    urn_no: {
      type: DataTypes.STRING(16),
      allowNull: true,
    },
    mobile_phone: {
      type: DataTypes.STRING(15),
      allowNull: true,
    },
    whatsapp_no: {
      type: DataTypes.STRING(45),
      allowNull: true,
    },
    identity_proof: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    id_proof_no: {
      type: DataTypes.STRING(30),
      allowNull: true,
    },
    pan_card_no: {
      type: DataTypes.STRING(16),
      allowNull: true,
    },
    door_no: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    street: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    landmark: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    pincode: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    district: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    state: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    village_name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    locality: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    loan_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    relationship: {
      type: DataTypes.STRING(45),
      allowNull: true,
    },
    hub_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    hub_name: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    spoke_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    spoke_name: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "Kinara_Engr_Api_DedupeApplicentDtl",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
DedupApplicantDetails.removeAttribute("id"); // Primary Key Attribute
DedupApplicantDetails.removeAttribute("createdAt"); // Created Date Attribute
DedupApplicantDetails.removeAttribute("updatedAt"); // Update Date Attribute
