/**
 * DESCRIPTION: Kinara_Engr_Api_LUC_Details data model used to
 *              Define Kinara_Engr_Api_LUC_Details ORM data model object and
 *              to fetch LUC  details (Loan utilization check)
 *              for all the Loans which are disbursed.
 * CREATED BY: ANITA MS
 * CREATED DATE: 01/06/2021
 * MODIFIED BY:
 * MODIFIED DATE:
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface ILUCModelAPI {
  state: string;
  region: string;
  hub: string;
  luc_id: string;
  customer_id: number;
  risk_officer_ID: number;
  entity_Name: number;
  address: number;
  proprietory_name: number;
  loan_id: number;
  account_number: number;
  entity_URN_no: number;
  loan_product_name: number;
  loan_purpose: number;
  loan_sub_purpose: number;
  loan_amount: number;
  disbursement_date_check: number;
  total_number_of_men: number;
  total_number_of_women: number;
  pre_loan_monthly_revenue: number;
  pre_loan_monthly_net_income: number;
  pre_loan_proprietor_salary: number;
  pre_loan_number_of_customers_or_buyers: number;
}

// Class that implements the LUC Details interface attributes
export class LUCModel extends Model<ILUCModelAPI> implements ILUCModelAPI {
  public state!: string;
  public region!: string;
  public hub!: string;
  public luc_id!: string;
  public customer_id!: number;
  public risk_officer_ID!: number;
  public entity_Name!: number;
  public address!: number;
  public proprietory_name!: number;
  public loan_id!: number;
  public account_number!: number;
  public entity_URN_no!: number;
  public loan_product_name!: number;
  public loan_purpose!: number;
  public loan_sub_purpose!: number;
  public loan_amount!: number;
  public disbursement_date_check!: number;
  public total_number_of_men!: number;
  public total_number_of_women!: number;
  public pre_loan_monthly_revenue!: number;
  public pre_loan_monthly_net_income!: number;
  public pre_loan_proprietor_salary!: number;
  public pre_loan_number_of_customers_or_buyers!: number;
}

// Initializing the database table structure
LUCModel.init(
  {
    state: {
      type: DataTypes.STRING(35),
      allowNull: true,
    },
    region: {
      type: DataTypes.STRING(35),
      allowNull: true,
    },
    hub: {
      type: DataTypes.STRING(35),
      allowNull: true,
    },
    luc_id: {
      type: DataTypes.STRING(20),
      allowNull: true,
    },
    customer_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    risk_officer_ID: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    entity_Name: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    address: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    proprietory_name: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    loan_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    account_number: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    entity_URN_no: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    loan_product_name: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    loan_purpose: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    loan_sub_purpose: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    loan_amount: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    disbursement_date_check: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    total_number_of_men: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    total_number_of_women: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    pre_loan_monthly_revenue: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    pre_loan_monthly_net_income: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    pre_loan_proprietor_salary: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    pre_loan_number_of_customers_or_buyers: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "Kinara_Engr_Api_LUC_Details",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
LUCModel.removeAttribute("id"); // Primary Key Attribute
LUCModel.removeAttribute("createdAt"); // Created Date Attribute
LUCModel.removeAttribute("updatedAt"); // Update Date Attribute
