/**
 * DESCRIPTION: Kinara_Engr_Api_Linkeddeposit DATA MODEL USED
 *              TO create the Linked deposit details
 * CREATED BY: ANITA MS
 * CREATED DATE: 01/06/2021
 * MODIFIED BY:
 * MODIFIED DATE:
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IDepositAPI {
  ID: number;
  Deposit_id: string;
  Account_number: string;
  Loan_id: string;
  Total_amount: number;
  Bill_id: string;
}

// Class that implements the Deposit Details interface attributes
export class DepositDetails extends Model<IDepositAPI> implements IDepositAPI {
  public ID!: number;
  public Deposit_id!: string;
  public Account_number!: string;
  public Loan_id!: string;
  public Total_amount!: number;
  public Bill_id!: string;
}

// Initializing the database table structure
DepositDetails.init(
  {
    ID: {
      type: DataTypes.BIGINT,
      allowNull: true,
    },
    Deposit_id: {
      type: DataTypes.STRING(5),
      allowNull: true,
    },
    Account_number: {
      type: DataTypes.STRING(20),
      allowNull: true,
    },
    Loan_id: {
      type: DataTypes.STRING(20),
      allowNull: true,
    },
    Total_amount: {
      type: DataTypes.DECIMAL(14, 3),
      allowNull: true,
    },
    Bill_id: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "Kinara_Engr_Api_Linkeddeposit",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
DepositDetails.removeAttribute("id"); // Primary Key Attribute
DepositDetails.removeAttribute("createdAt"); // Created Date Attribute
DepositDetails.removeAttribute("updatedAt"); // Update Date Attribute
