/**
 * DESCRIPTION:Kinara_Engr_Api_OverallDemand DATA MODEL USED
 *              TO create the overallDemand
 * CREATED BY: ANITA MS
 * CREATED DATE: 01/06/2021
 * MODIFIED BY:
 * MODIFIED DATE:
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IOveralDemandAPI {
  partner_name: string;
  Parent_Branch: string;
  Hub: string;
  Spoke: string;
  ClientID: string;
  AccountID: string;
  ProductName: string;
  ClientName: string;
  Proprietor_Name: string;
  InstallmentDueDate: Date;
  LoanAmount: number;
  Cheque_ID: number;
  Current_Due: number;
  installment_number: number;
  Term: number;
  Repayment_Mode: string;
  Bank_Name: string;
  Branch_Name: string;
  Realization_Status: string;
  Realization_Reason: string;
  Realization_Date: Date;
  Mobile_No: number;
}

// Class that implements the bill Details interface attributes
export class OveralDemand
  extends Model<IOveralDemandAPI>
  implements IOveralDemandAPI
{
  public partner_name!: string;
  public Parent_Branch!: string;
  public Hub!: string;
  public Spoke!: string;
  public ClientID!: string;
  public AccountID!: string;
  public ProductName!: string;
  public ClientName!: string;
  public Proprietor_Name!: string;
  public InstallmentDueDate!: Date;
  public LoanAmount!: number;
  public Cheque_ID!: number;
  public Current_Due!: number;
  public installment_number!: number;
  public Term!: number;
  public Repayment_Mode!: string;
  public Bank_Name!: string;
  public Branch_Name!: string;
  public Realization_Status!: string;
  public Realization_Reason!: string;
  public Realization_Date!: Date;
  public Mobile_No!: number;
}

// Initializing the database table structure
OveralDemand.init(
  {
    partner_name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    Parent_Branch: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    Hub: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    Spoke: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    ClientID: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    AccountID: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    ProductName: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    ClientName: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    Proprietor_Name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    InstallmentDueDate: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    LoanAmount: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    Cheque_ID: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    Current_Due: {
      type: DataTypes.DOUBLE,
      allowNull: true,
    },
    installment_number: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    Term: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    Repayment_Mode: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    Bank_Name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    Branch_Name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    Realization_Status: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    Realization_Reason: {
      type: DataTypes.STRING(255),
      allowNull: true,
    },
    Realization_Date: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    Mobile_No: {
      type: DataTypes.DOUBLE,
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "Kinara_Engr_Api_OverallDemand",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
//OveralDemand.removeAttribute("id"); // Primary Key Attribute
OveralDemand.removeAttribute("createdAt"); // Created Date Attribute
OveralDemand.removeAttribute("updatedAt"); // Update Date Attribute
