/**
 * DESCRIPTION: KINARA_ENGR_API_TOKENS DATA MODEL
 *              USED TO CAPTURES THE USER TOKENS
 *              WHO HAVE LOGGED-IN
 * CREATED BY: VIKAS
 * CREATED DATE: 27/04/2021
 * MODIFIED BY: VIKAS
 * MODIFIED DATE: 19/05/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IAPIToken {
  user_Id: number;
  token: string;
  token_status: string;
  created_timest: Date;
}

// Class that implements the api token interface attributes
export class APIToken extends Model<IAPIToken> implements IAPIToken {
  public user_Id!: number;
  public token!: string;
  public token_status!: string;
  public created_timest!: Date;
}

// Initializing the database table structure
APIToken.init(
  {
    user_Id: {
      type: DataTypes.INTEGER,
    },
    token: {
      type: DataTypes.STRING(2500),
    },
    token_status: {
      type: DataTypes.STRING(50),
    },
    created_timest: {
      type: DataTypes.DATE,
    },
  },
  {
    timestamps: false,
    tableName: "Kinara_Engr_Api_Tokens",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
APIToken.removeAttribute("id"); // Primary Key Attribute
APIToken.removeAttribute("createdAt"); // Created Date Attribute
APIToken.removeAttribute("updatedAt"); // Update Date Attribute
