/**
 * DESCRIPTION: KINARA_ENGR_API_USERS DATA MODEL
 *              USED TO FETCH THE USER DETAILS
 * CREATED BY: VIKAS
 * CREATED DATE: 27/04/2021
 * MODIFIED BY: VIKAS
 * MODIFIED DATE: 19/05/2021
 */
import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface for the attributes, for stricter typechecking
interface IAPIUsers {
  ID: number;
  owner_name: string;
  user_name: string;
  password: string;
  api_access_level: string;
  user_status: string;
}

// Class that implements the api users interface attributes
export class APIUsers extends Model<IAPIUsers> {
  public ID!: number;
  public owner_name!: string;
  public user_name!: string;
  public password!: string;
  public api_access_level!: string;
  public user_status!: string;
}

// Initializing the database table structure
APIUsers.init(
  {
    ID: {
      type: DataTypes.INTEGER,
      primaryKey: true,
    },
    owner_name: {
      type: DataTypes.STRING(50),
    },
    user_name: {
      type: DataTypes.STRING(50),
    },
    password: {
      type: DataTypes.STRING(100),
    },
    api_access_level: {
      type: DataTypes.STRING(500),
    },
    user_status: {
      type: DataTypes.STRING(20),
    },
  },
  {
    timestamps: false,
    tableName: "Kinara_Engr_Api_Users",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
APIUsers.removeAttribute("id"); // Primary Key Attribute
APIUsers.removeAttribute("createdAt"); // Created Date Attribute
APIUsers.removeAttribute("updatedAt"); // Update Date Attribute
