/**
 * DESCRIPTION: KINARA_ENGR_API_ZOHO_CRM DATA MODEL USED TO
 *              FETCH THE ZOHO DETAILS
 * CREATED BY: ANITA MS
 * CREATED DATE: 10/05/2021
 * MODIFIED BY: ANITA MS
 * MODIFIED DATE: 22/06/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes or parameters, for strict typechecking, used in the engrapis
interface IZohoAPI {
  business_name: string;
  account_name: string;
  door_no: string;
  email: string;
  post_office: string;
  area: string;
  state: string;
  pincode: number;
  region_name: string;
  company_operating_since: Date;
  loan_amount: number;
  business_type: string;
  customer_id: number;
  tenure: number;
  mobile_no: string;
  loan_id: number;
  no_of_installments_repaid: number;
  customer_bank: string;
  date_of_birth: Date;
  loan_subpurpose: string;
  first_payment_date: Date;
  hub_name: string;
  district: string;
  Gender: string;
  first_name: string;
  account_number: string;
  customer_type: string;
  bounce_if_any: string;
  created_at: Date;
  last_updated_at: Date;
  contact_name: string;
  loan_name: string;
  stage: string;
}

// Class that implements the zoho crm interface attributes
export class ZohoCRM extends Model<IZohoAPI> implements IZohoAPI {
  // Note that the `null assertion` `!` is required in strict mode.
  public business_name!: string;
  public account_name!: string;
  public door_no!: string;
  public email!: string;
  public post_office!: string;
  public area!: string;
  public state!: string;
  public pincode!: number;
  public region_name!: string;
  public company_operating_since!: Date;
  public loan_amount!: number;
  public business_type!: string;
  public customer_id!: number;
  public tenure!: number;
  public mobile_no!: string;
  public loan_id!: number;
  public no_of_installments_repaid!: number;
  public customer_bank!: string;
  public date_of_birth!: Date;
  public loan_subpurpose!: string;
  public first_payment_date!: Date;
  public hub_name!: string;
  public district!: string;
  public Gender!: string;
  public first_name!: string;
  public account_number!: string;
  public customer_type!: string;
  public bounce_if_any!: string;
  public created_at!: Date;
  public last_updated_at!: Date;
  public contact_name!: string;
  public loan_name!: string;
  public stage!: string;
}

// Initializing the database table structure for KINARA_ENGR_API_ZOHO_CRM table
ZohoCRM.init(
  {
    business_name: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    account_name: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    door_no: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    email: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    post_office: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    area: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    state: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    pincode: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    region_name: {
      type: DataTypes.STRING(35),
      allowNull: true,
    },
    company_operating_since: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    loan_amount: {
      type: DataTypes.DOUBLE,
      allowNull: true,
    },
    business_type: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    customer_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    tenure: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    mobile_no: {
      type: DataTypes.STRING(12),
      allowNull: true,
    },
    loan_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    no_of_installments_repaid: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    customer_bank: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    date_of_birth: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    loan_subpurpose: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    first_payment_date: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    hub_name: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    district: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    Gender: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    first_name: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    account_number: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },

    customer_type: {
      type: DataTypes.STRING(10),
      allowNull: true,
    },
    bounce_if_any: {
      type: DataTypes.STRING(3),
      allowNull: true,
    },
    created_at: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    last_updated_at: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    contact_name: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    loan_name: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    stage: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "Kinara_Engr_Api_zoho_crm",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
ZohoCRM.removeAttribute("id"); // Primary Key Attribute
ZohoCRM.removeAttribute("createdAt"); // Created Date Attribute
ZohoCRM.removeAttribute("updatedAt"); // Update Date Attribute
