/**
 * DESCRIPTION: CALCULATE_ORIGINAL_REPAYMENT_SCHEDULE DATA MODEL USED
 *              TO FETCH THE CUSTOMER ORIGINAL PAYMENT SCHEDULE
 * CREATED BY: VIKAS
 * CREATED DATE: 28/04/2021
 * MODIFIED BY: VIKAS
 * MODIFIED DATE: 19/05/2021
 */
import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IOriginalRepaymentSchedule {
  loan_id: number;
  installment_date: Date;
  installment_amount: number;
  demand_no: number;
  principal_amount: number;
  interest_amount: number;
  calculated_principal_outstanding_amount: number;
}

// Class that implements the original repayment schedule interface attributes
export class OriginalRepaymentSchedule
  extends Model<IOriginalRepaymentSchedule>
  implements IOriginalRepaymentSchedule
{
  // Note that the `null assertion` `!` is required in strict mode.
  public loan_id!: number;
  public installment_date!: Date;
  public installment_amount!: number;
  public demand_no!: number;
  public principal_amount!: number;
  public interest_amount!: number;
  public calculated_principal_outstanding_amount!: number;
}

// Initializing the database table structure
OriginalRepaymentSchedule.init(
  {
    loan_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    installment_date: {
      type: DataTypes.DATEONLY,
      allowNull: true,
    },
    installment_amount: {
      type: DataTypes.FLOAT(12, 2),
      allowNull: true,
    },
    demand_no: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    principal_amount: {
      type: DataTypes.FLOAT(12, 2),
      allowNull: true,
    },
    interest_amount: {
      type: DataTypes.FLOAT(12, 2),
      allowNull: true,
    },
    calculated_principal_outstanding_amount: {
      type: DataTypes.FLOAT(12, 2),
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "calculated_original_repayment_schedule",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
OriginalRepaymentSchedule.removeAttribute("id"); // Primary Key Attribute
OriginalRepaymentSchedule.removeAttribute("createdAt"); // Created Date Attribute
OriginalRepaymentSchedule.removeAttribute("updatedAt"); // Update Date Attribute
