/**
 * DESCRIPTION: CUSTOMER_API DATA MODEL USED
 *              TO FETCH THE CUSTOMER DETAILS
 * CREATED BY: VIKAS
 * CREATED DATE: 28/04/2021
 * MODIFIED BY: VIKAS
 * MODIFIED DATE: 19/05/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface ICustomerAPI {
  customer_id: number;
  account_number: string;
  customer_bank_name: string;
  area: string;
  branch_name: string;
  operating_since: Date;
  business_urn: string;
}

// Class that implements the customer api interface attributes
export class CustomerAPI extends Model<ICustomerAPI> implements ICustomerAPI {
  public customer_id!: number;
  public account_number!: string;
  public customer_bank_name!: string;
  public area!: string;
  public branch_name!: string;
  public operating_since!: Date;
  public business_urn!: string;
}

// Initializing the database table structure
CustomerAPI.init(
  {
    customer_id: {
      type: DataTypes.BIGINT,
      allowNull: true,
    },
    account_number: {
      type: DataTypes.STRING(50),
      allowNull: true,
    },
    customer_bank_name: {
      type: DataTypes.STRING(300),
      allowNull: true,
    },
    area: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    branch_name: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
    operating_since: {
      type: DataTypes.DATEONLY,
      allowNull: true,
    },
    business_urn: {
      type: DataTypes.STRING(100),
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "customer_api",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
CustomerAPI.removeAttribute("id"); // Primary Key Attribute
CustomerAPI.removeAttribute("createdAt"); // Created Date Attribute
CustomerAPI.removeAttribute("updatedAt"); // Update Date Attribute
