/**
 * DESCRIPTION: KINARA_ENGR_API_HIST_TABLE DATA MODEL USED
 *              TO LOG THE API HITS
 * CREATED BY: VIKAS
 * CREATED DATE: 27/04/2021
 * MODIFIED BY: VIKAS
 * MODIFIED DATE: 19/05/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IAPIHistoryTable {
  application_id: string;
  user_id: string;
  api_route: string;
  api_name: string;
  api_error_label: string;
  status_code: number;
  api_status: string;
  logic_status: string;
  api_request: string;
  api_response: string;
  server_type: string;
  api_request_on: string;
}

// Class that implements the api history table interface attributes
export class APIHistoryTable
  extends Model<IAPIHistoryTable>
  implements IAPIHistoryTable
{
  public application_id!: string;
  public user_id!: string;
  public api_route!: string;
  public api_name!: string;
  public api_error_label!: string;
  public status_code!: number;
  public api_status!: string;
  public logic_status!: string;
  public api_request!: string;
  public api_response!: string;
  public server_type!: string;
  public api_request_on!: string;
}

// Initializing the database table structure
APIHistoryTable.init(
  {
    application_id: {
      type: DataTypes.TEXT,
    },
    user_id: {
      type: DataTypes.TEXT,
    },
    api_route: {
      type: DataTypes.TEXT,
    },
    api_name: {
      type: DataTypes.TEXT,
    },
    api_error_label: {
      type: DataTypes.TEXT,
    },
    status_code: {
      type: DataTypes.BIGINT,
    },
    api_status: {
      type: DataTypes.TEXT,
    },
    logic_status: {
      type: DataTypes.TEXT,
    },
    api_request: {
      type: DataTypes.TEXT,
    },
    api_response: {
      type: DataTypes.TEXT,
    },
    server_type: {
      type: DataTypes.TEXT,
    },
    api_request_on: {
      type: DataTypes.DATE,
    },
  },
  {
    timestamps: false,
    tableName: "kinara_engr_api_hist_table",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
APIHistoryTable.removeAttribute("id"); // Primary Key Attribute
APIHistoryTable.removeAttribute("createdAt"); // Created Date Attribute
APIHistoryTable.removeAttribute("updatedAt"); // Update Date Attribute
