/**
 * DESCRIPTION:  OZONETEL CALL SUMMARY DETAILS DATA MODEL
 * CREATED BY: RAKESH ANUGULA
 * CREATED DATE: 22/04/2021
 * MODIFIED BY: VIKAS
 * MODIFIED DATE: 10/05/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IOzonetelCallSummary {
  AgentID: string;
  AgentName: string;
  AgentPhoneNumber: string;
  AgentStatus: string;
  AgentUniqueID: string;
  Apikey: string;
  AudioFile: string;
  CallDuration: string;
  CallerConfAudioFile: string;
  CallerID: string;
  CampaignName: string;
  CampaignStatus: string;
  Comments: string;
  ConfDuration: string;
  CustomerStatus: string;
  DialStatus: string;
  DialedNumber: string;
  Did: string;
  Disposition: string;
  Duration: string;
  EndTime: string;
  FallBackRule: string;
  HangupBy: string;
  Location: string;
  monitorUCID: string;
  PhoneName: string;
  Skill: string;
  StartTime: string;
  Status: string;
  TimeToAnswer: string;
  TransferType: string;
  TransferredTo: string;
  Type: string;
  UserName: string;
  UUI: string;
}

// Class that implements the ozonetel call summary details interface attributes
export class OzonetelCallSummaryDetail
  extends Model<IOzonetelCallSummary>
  implements IOzonetelCallSummary
{
  public AgentID!: string;
  public AgentName!: string;
  public AgentPhoneNumber!: string;
  public AgentStatus!: string;
  public AgentUniqueID!: string;
  public Apikey!: string;
  public AudioFile!: string;
  public CallDuration!: string;
  public CallerConfAudioFile!: string;
  public CallerID!: string;
  public CampaignName!: string;
  public CampaignStatus!: string;
  public Comments!: string;
  public ConfDuration!: string;
  public CustomerStatus!: string;
  public DialStatus!: string;
  public DialedNumber!: string;
  public Did!: string;
  public Disposition!: string;
  public Duration!: string;
  public EndTime!: string;
  public FallBackRule!: string;
  public HangupBy!: string;
  public Location!: string;
  public monitorUCID!: string;
  public PhoneName!: string;
  public Skill!: string;
  public StartTime!: string;
  public Status!: string;
  public TimeToAnswer!: string;
  public TransferType!: string;
  public TransferredTo!: string;
  public Type!: string;
  public UserName!: string;
  public UUI!: string;
}

// Initializing the database table structure
OzonetelCallSummaryDetail.init(
  {
    AgentID: {
      type: DataTypes.STRING(20),
    },
    AgentName: {
      type: DataTypes.STRING(20),
    },
    AgentPhoneNumber: {
      type: DataTypes.STRING(20),
    },
    AgentStatus: {
      type: DataTypes.STRING(20),
    },
    AgentUniqueID: {
      type: DataTypes.STRING(20),
    },
    Apikey: {
      type: DataTypes.STRING(20),
    },
    AudioFile: {
      type: DataTypes.STRING(250),
    },
    CallDuration: {
      type: DataTypes.STRING(10),
    },
    CallerConfAudioFile: {
      type: DataTypes.STRING(250),
    },
    CallerID: {
      type: DataTypes.STRING(20),
    },
    CampaignName: {
      type: DataTypes.STRING(20),
    },
    CampaignStatus: {
      type: DataTypes.STRING(10),
    },
    Comments: {
      type: DataTypes.STRING(1000),
    },
    ConfDuration: {
      type: DataTypes.STRING(10),
    },
    CustomerStatus: {
      type: DataTypes.STRING(15),
    },
    DialStatus: {
      type: DataTypes.STRING(15),
    },
    DialedNumber: {
      type: DataTypes.STRING(20),
    },
    Did: {
      type: DataTypes.STRING(20),
    },
    Disposition: {
      type: DataTypes.STRING(200),
    },
    Duration: {
      type: DataTypes.STRING(10),
    },
    EndTime: {
      type: DataTypes.STRING(50),
    },
    FallBackRule: {
      type: DataTypes.STRING(25),
    },
    HangupBy: {
      type: DataTypes.STRING(20),
    },
    Location: {
      type: DataTypes.STRING(100),
    },
    monitorUCID: {
      type: DataTypes.STRING(50),
      primaryKey: true,
    },
    PhoneName: {
      type: DataTypes.STRING(20),
    },
    Skill: {
      type: DataTypes.STRING(50),
    },
    StartTime: {
      type: DataTypes.STRING(50),
    },
    Status: {
      type: DataTypes.STRING(15),
    },
    TimeToAnswer: {
      type: DataTypes.STRING(10),
    },
    TransferType: {
      type: DataTypes.STRING(20),
    },
    TransferredTo: {
      type: DataTypes.STRING(50),
    },
    Type: {
      type: DataTypes.STRING(20),
    },
    UserName: {
      type: DataTypes.STRING(20),
    },
    UUI: {
      type: DataTypes.STRING(20),
    },
  },
  {
    timestamps: false,
    tableName: "ozonetelCallSummaryDetail",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
OzonetelCallSummaryDetail.removeAttribute("id"); // Primary Key Attribute
OzonetelCallSummaryDetail.removeAttribute("createdAt"); // Created Date Attribute
OzonetelCallSummaryDetail.removeAttribute("updatedAt"); // Update Date Attribute
