/**
 * DESCRIPTION: PIN_CODE_API DATA MODEL USED TO
 *              DETAILS BASED ON THE PIN CODE
 * CREATED BY: VIKAS
 * CREATED DATE: 27/04/2021
 * MODIFIED BY: VIKAS
 * MODIFIED DATE: 10/05/2021
 */

import { DataTypes, Model } from "sequelize";
import { DbConnection } from "../util/dbConfig";
const sequelize = new DbConnection().connectMySql();

// Interface defines the attributes, for strict typechecking
interface IPINCodeAPI {
  sales_officer_id: String;
  sales_officer_Firstname: string;
  sales_officer_Lastname: String;
  role_designation: String;
  zone_id: String;
  zone_name: String;
  state_id: String;
  state_name: String;
  division_id: String;
  division_name: String;
  region_id: String;
  region_name: String;
  hub_id: Number;
  hubname: String;
  spoke_id: Number;
  spoke_name: String;
  pincode: Number;
}

// Class that implements the pin code api interface attributes
export class PINCodeAPI extends Model<IPINCodeAPI> implements IPINCodeAPI {
  public sales_officer_id!: String;
  public sales_officer_Firstname!: string;
  public sales_officer_Lastname!: String;
  public role_designation!: String;
  public zone_id!: String;
  public zone_name!: String;
  public state_id!: String;
  public state_name!: String;
  public division_id!: String;
  public division_name!: String;
  public region_id!: String;
  public region_name!: String;
  public hub_id!: Number;
  public hubname!: String;
  public spoke_id!: Number;
  public spoke_name!: String;
  public pincode!: Number;
}

// Initializing the database table structure
PINCodeAPI.init(
  {
    sales_officer_id: {
      type: DataTypes.STRING(40),
      allowNull: true,
    },
    sales_officer_Firstname: {
      type: DataTypes.STRING(150),
      allowNull: true,
    },
    sales_officer_Lastname: {
      type: DataTypes.STRING(150),
      allowNull: true,
    },
    role_designation: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    zone_id: {
      type: DataTypes.STRING(10),
      allowNull: true,
    },
    zone_name: {
      type: DataTypes.STRING(35),
      allowNull: true,
    },
    state_id: {
      type: DataTypes.STRING(10),
      allowNull: true,
    },
    state_name: {
      type: DataTypes.STRING(35),
      allowNull: true,
    },
    division_id: {
      type: DataTypes.STRING(10),
      allowNull: true,
    },
    division_name: {
      type: DataTypes.STRING(35),
      allowNull: true,
    },
    region_id: {
      type: DataTypes.STRING(10),
      allowNull: true,
    },
    region_name: {
      type: DataTypes.STRING(35),
      allowNull: true,
    },
    hub_id: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
    hubname: {
      type: DataTypes.STRING(35),
      allowNull: true,
    },
    spoke_id: {
      type: DataTypes.BIGINT,
      allowNull: true,
    },
    spoke_name: {
      type: DataTypes.STRING(200),
      allowNull: true,
    },
    pincode: {
      type: DataTypes.INTEGER,
      allowNull: true,
    },
  },
  {
    timestamps: false,
    tableName: "pin_code_api",
    sequelize, // passing the `sequelize` instance is required
    freezeTableName: true,
  }
);

// Remove the attributes that are auto created by Sequelize
PINCodeAPI.removeAttribute("id"); // Primary Key Attribute
PINCodeAPI.removeAttribute("createdAt"); // Created Date Attribute
PINCodeAPI.removeAttribute("updatedAt"); // Update Date Attribute
