/**
 * DESCRIPTION: CAPTURE HISTORY LOGS ON SUCCESS, FAILURE & VALIDATION FUNCTIONS
 * CREATED BY: VIKAS
 * CREATED DATE: 25/03/2021
 * MODIFIED BY: VIKAS
 * MODIFIED DATE: 07/05/2021
 */
import { Request, Response } from "express";
import * as APIHist from "../util/addAPIHist";

/**
 * @desc    Send any success response
 *
 * @param   {number} statusCode - A number param.
 * @param   {object} data - An object param.
 * @param   {Request} req - A api request param.
 */
export class success {
  constructor(statusCode: number, data: object, req: Request) {
    const response = {
      status: statusCode,
      success: true,
      data,
    };

    return new Promise(async (resolve, reject) => {
      // Capture the details in a data table.
      await APIHist.add_api_call(
        req,
        JSON.parse(JSON.stringify(response)),
        "NA",
        "SUCCESS",
        "SUCCESS",
        statusCode
      );

      //Return the reponse.
      resolve(response);
    });
  }
}

/**
 * @desc    Send any error response
 *
 * @param   {Request} req - A request param.
 * @param   {Response} error - A response param.
 * @param   {string} apiErrorLabel - A string param.
 * @param   {string} logicStatus - A string param.
 * @param   {number} statusCode - A number param.
 *
 */
export class error {
  constructor(
    req: Request,
    error: Response,
    apiErrorLabel: string,
    logicStatus: string,
    statusCode: number
  ) {
    // List of common HTTP request code
    const codes = [204, 400, 401, 404, 403, 422, 500];

    // Get matched code
    statusCode = codes.find((code) => code == statusCode) || 500;

    const response = {
      status: statusCode,
      success: false,
      error,
    };
    return new Promise(async (resolve, reject) => {
      // Capture the details in a data table.

      await APIHist.add_api_call(
        req,
        JSON.parse(JSON.stringify(response)),
        apiErrorLabel,
        "FAIL",
        logicStatus,
        statusCode
      );

      //Return the reponse.
      resolve(response);
    });
  }
}
